@ECHO OFF
BAX %0 %1 %2 %3 %4 %5 %6 %7 %8 %9
GOTO SKIPBAX
'******************************************************************
'* This program is of the "program launcher" genre.  It shows the *
'* technique for selecting a program to run by using BAX but the  *
'* program is actually executed by BAX's underlying batch file.   *
'* The dummy batch file AFTERBAX.BAT is written by the BAX        *
'* program and is then called by the underlying batch file after  *
'* the BAX program has terminated.  The advantage to this is that *
'* the memory occupied by BAX (usually about 70K) is released     *
'* back into the DOS memory pool and is available to the program  *
'* which is executed by AFTERBAX.BAT.  Unless you have super      *
'* memory hungry programs, this technique is usually not worth    *
'* the extra coding effort, but sometimes you have a program that *
'* needs every byte it can get, so it's good to have this method  *
'* in your coding "bag of tricks".  See the "doc box" at the      *
'* end of this program for further info.                          *
'*                                                                *
'* See the program MAXMEM2.BAT for an alternate method of freeing *
'* up memory for use by a called program.                         *
'*                                                                *
'******************************************************************
=maxmem1        ' LOWER CASE LABEL MEANS MIXED CASE INPUT
CALL =COLORSUB  ' SET UP COLOR NAMES
%RC = 1         ' STANDARD RETURN CODE (ERRORLEVEL)
'
%P1 = PROGRAM1  ' PROGRAM NAMES
%P2 = PROGRAM2
%P3 = PROGRAM3
'
%S1 = LIT *****************************************************
%S2 = LIT *            SELECT A PROGRAM BY NUMBER             *
%S3 = LIT *                                                   *
%S4 = LIT *                1 --                               *
%S5 = LIT *                2 --                               *
%S6 = LIT *                3 --                               *
%S7 = LIT *                                                   *
%S8 = LIT *            ALL OTHER KEYS RETURN TO DOS           *
%S9 = LIT *****************************************************
'
%S4 = OVERLAY %S4 %P1 23             ' PUT PROGRAM NAMES IN BOX
%S5 = OVERLAY %S5 %P2 23
%S6 = OVERLAY %S6 %P3 23
'
COLORS %BLACK %RED                   ' USE A RED BACKGROUND
CLS                                  ' PAINT THE SCREEN RED
COLORS %YELLOW %BROWN                ' YELLOW ON BROWN FOR BOX COLOR
%X = 0                               ' SET LOOP COUNTER
LOOP =BOTBOX                         ' TOP OF LOOP TO DRAW BOX
%X = ADD %X 1                        ' INCREMENT COUNTER
IF %X > 9 THEN LEAVE =BOTBOX         ' BREAK LOOP
CURSORVH 0 15                        ' POSITION CURSOR IN COLUMN 15
OUTMSG %S%X                          ' DISPLAY TEXT ON SCREEN
OUTPUT                               ' MOVE CURSOR DOWN ONE LINE
=BOTBOX                              ' BOTTOM OF LOOP
OUTPUT                               ' DISPLAY BLANK LINE (COSMETIC)
'
CURSORVH 0 15                        ' POSITION CURSOR
OUTMSG PROGRAM NUMBER ->             ' OUTPUT OUR MESSAGE
%K = INPUTK                          ' GET A KEYSTROKE
IF %K < 49 THEN GOTO =DONE           ' LESS THAN 1, TERMINATE
IF %K > 51 THEN GOTO =DONE           ' MORE THAN 3, TERMINATE
%K = SUB %K 48                       ' RESOLVE KEYSTROKE TO 1,2 OR 3
'
OUTPUT                               ' MOVE CURSOR TO NEXT LINE
OUTPUT                               ' GO ONE MORE
COLORS %YELLOW %MAGENTA              ' SET COLORS FOR ARGUMENT PROMPT
OUTMSG ARGUMENTS FOR %P%K ->         ' OUTPUT THE PROMPT MSG
%ARGS = %N                           ' NULL STRING, LET BAX FIGURE LENGTH
COLORS %WHITEX %BLUE                 ' COLORS FOR INPUT AREA
INPUT %ARGS                          ' GET THE ARGUMENT LIST
OUTPUT                               ' MOVE CURSOR TO NEXT LINE
COLORS %YELLOW %BROWN                ' RETURN TO ORIGINAL COLOR SCHEME
OPENOUT AFTERBAX.BAT                 ' OPEN OUR DUMMY BAT FILE
OUTPUTF @ECHO OFF                    ' KILL BATCH FILE ECHO
OUTPUTF CLS                          ' CLEAR THE SCREEN
OUTPUTF %P%K %ARGS                   ' WRITE PROGRAM NAME AND ARGUMENTS
'
'NOTE: IF PROGRAM IS A BATCH FILE, USE: OUTPUTF CALL %P%K %ARGS
'
CLOSEOUT                             ' CLOSE THE FILE
%RC = 0                              ' SET ERRORLEVEL FOR BATCH FILE
=DONE
OUTPUT                               ' COSMETIC BLANK LINE
STOP %RC                             ' TERMINATE WITH ERRORLEVEL
'
=COLORSUB         ' SUB-ROUTINE TO ASSIGN MEANINGFUL NAMES TO COLORS
'
%BLACK    =  0    ' NOTE: IF YOU ADD 8 TO ANY OF THESE YOU
%BLUE     =  1    ' WILL GET THE SAME COLOR, ONLY BRIGHTER.
%GREEN    =  2
%CYAN     =  3
%RED      =  4
%MAGENTA  =  5
%BROWN    =  6
%WHITE    =  7
'                  **** BRIGHTER COLORS ****
%GRAY     =  8     ' A BRIGHT BLACK IS GRAY
%BLUEX    =  9
%GREENX   = 10     ' BRIGHT COLORS MAY ONLY BE USED IN THE FOREGROUND
%CYANX    = 11
%REDX     = 12
%MAGENTAX = 13
%YELLOW   = 14     ' A BRIGHT BROWN IS YELLOW
%WHITEX   = 15
'
RETURN
END
'
'******************************************************************
'* When our bax program terminates, control is passed to the      *
'* batch file :SKIPBAX label.  If we terminated with a return     *
'* code (errorlevel) of 1, it means that we did not write an      *
'* AFTERBAX.BAT file, so our batch file can simply terminate also.*
'* If we terminated with a return code of zero, it tells our      *
'* batch file that we wrote AFTERBAX.BAT, so our batch file calls *
'* AFTERBAX.BAT and then after AFTERBAX.BAT executes, control is  *
'* returned into our batch file.  It then deletes AFTERBAX.BAT    *
'* and stops.  Since we are using the batch file CALL statement,  *
'* you must have at least version 3.3 of DOS.  this technique     *
'* will work with versions of DOS prior to 3.3 but you cannot     *
'* use CALL.  You can probably get the same results by using      *
'* the DOS COMMAND command. (See your DOS manual for syntax.)     *
'*                                                                *
'* One other problem that can arise is that if you are executing  *
'* programs that change drives and/or directories and do not have *
'* the decency to return you to the directory where you started,  *
'* then our underlying batch file is not going to know where      *
'* AFTERBAX.BAT is located, so the DEL command will fail.  You    *
'* can get around this problem by coding a path in front of       *
'* AFTERBAX.BAT when you write it and also in the batch file      *
'* statements which reference AFTERBAX.BAT following the :SKIPBAX *
'* label.                                                         *
'* The program MAXMEM2.BAX uses a different technique which does  *
'* not require a scratch batch file, so you might investigate     *
'* that option also.                                              *
'******************************************************************
'
:SKIPBAX
IF ERRORLEVEL 1 GOTO NOMORE
CALL AFTERBAX.BAT
DEL AFTERBAX.BAT
:NOMORE
